import Base.show, Base.print

mutable struct DataVPP
  num_items::Int
  num_dim::Int
  weights::Array{Array{Int}}
  capacities::Array{Int}
end

function readVPPData(path_file::String)
  # STEP 1 : pushing data in a vector.
  data = Array{Int,1}()
  open(path_file) do file
    for line in eachline(file)
       for peaceofdata in split(line)
         push!(data, parse(Int, peaceofdata))
       end
     end
  end

  num_items = data[1]
  num_dim = data[2]
  capacities = [data[j+2] for j in 1:num_dim]
  weights = [[data[2 + t*num_dim + j] for j in 1:num_dim] for t in 1:num_items]
  DataVPP(num_items, num_dim, weights, capacities)
end

function show(io::IO, d::DataVPP)
  println(io, "Vector Packing dataset.")
  println(io, "number of items = $(d.num_items)")
  println(io, "number of dimensions = $(d.num_dim)")
  println(io, "Capacities : ")
  for j in 1:d.num_dim
    println(io, "\t dimension $j, capacity= $(d.capacities[j])")
  end
  println(io, "Weights : ")
  for t in 1:d.num_items
    println(io, "\t item $t, weight= $(d.weights[t])")
  end
end

items(d::DataVPP) = [i for i in 1:d.num_items]
dimensions(d::DataVPP) = [i for i in 1:d.num_dim]
