
function build_model(data::DataVPP)

   T = items(data) 
   D = dimensions(data) 

   # Formulation
   vpp = VrpModel()
   @variable(vpp.formulation, x[t in vcat([0], T)] >= 0, Int)
   @constraint(vpp.formulation, cov[t in T], x[t] == 1.0)

   # Objective function
   @objective(vpp.formulation, Min, x[0])

   # Build the model directed graph G=(V,A)
   function buildgraph()

      V = vcat([0], T) 
      v_source, v_sink = 0, length(T)

      L, U = 0, length(T) # multiplicity
      G = VrpGraph(vpp, V, v_source, v_sink, (L, U))

      resources = []
      for d in D
         R_d = add_resource!(G, main = true) # R = Rᴹ = {1}
         for i in V
            l_i, u_i = 0.0, data.capacities[d] # accumulated resource consumption interval [l_i, u_i] for the vertex i
            set_resource_bounds!(G, i, R_d, l_i, u_i)
         end
	      push!(resources, R_d)
      end

      # Build set of arcs
      for i in 1:length(T)
         arc_id = add_arc!(G, i-1, i)
         if i == 1
            add_arc_var_mapping!(G, arc_id, x[0])
         end
         for d in D
            set_arc_consumption!(G, arc_id, resources[d], 0.0)
         end

         arc_id = add_arc!(G, i-1, i)
         add_arc_var_mapping!(G, arc_id, x[i])
         if i == 1
            add_arc_var_mapping!(G, arc_id, x[0])
         end
         for d in D
            set_arc_consumption!(G, arc_id, resources[d], data.weights[i][d])
         end
      end

      return G
   end

   G = buildgraph()
   add_graph!(vpp, G)

   A = get_arc_set(G)
   set_arc_packing_sets!(vpp, [[(G,id) for (i,j,id) in A if (j==t && get_arc_consumption(G, id, 1) != 0)] for t in T])

   enable_resource_consumption_branching!(vpp, 2)
   enable_packset_ryanfoster_branching!(vpp, 1)

   return (vpp, x)
end
